@@ -2,6 +2,6 @@
 
 from histoprint.formatter import HistFormatter, print_hist, text_hist
 
-from .version import version as __version__  # noqa: F401
+from .version import version as __version__
 
-__all__ = ("print_hist", "text_hist", "formatter", "HistFormatter")
+__all__ = ("print_hist", "text_hist", "formatter", "HistFormatter", "__version__")
